import React, { useEffect, useRef, useState } from 'react'
import Taro from '@tarojs/taro'
import { Canvas, View } from '@tarojs/components'
import { getConfig } from './config'
import posterSDKFactory from './sdk'

export default (props) => {
  const { dataSource, onStart, onEnd, onError } = props

  const [sdk, setSDK] = useState()
  const processing = useRef(false)

  const config = useRef()
  config.current = getConfig()

  useEffect(() => {
    Taro.nextTick(() => {
      posterSDKFactory('#canvas-poster').then((res) => {
        res.initCanvas({
          ...config.current,
        })
        setSDK(res)
      })
    })
  }, [])

  useEffect(() => {
    const { poster, miniCode, name, avatar, desc = '长按识别在线看房',  } = dataSource || {}
    if (sdk && poster && !processing.current) {
      onStart()
      processing.current = true
      const conf = config.current
      
      sdk.onError((err) => {
        if (onError) {
          onError(err)
        } else {
          console.error(err)
        }
      })

      Promise.all([
        sdk.getImage(poster),
        sdk.getImage(miniCode),
        sdk.getImage(avatar),
      ]).then((res) => {
        const [posterImg, miniCodeImg, avatarImg] = res

        // 封面
        sdk.drawImage(posterImg, conf.poster)
        // 头像
        sdk.drawImage(avatarImg, conf.avatar)
        // 小程序码
        sdk.drawImage(miniCodeImg, conf.miniCode)
        // 名称
        sdk.darwText(name, conf.name)
        // 小程序码
        sdk.darwText(desc, conf.desc)

        //
        const image = sdk.toDataURL()
        onEnd(image, sdk)
      }).catch(([e1, e2, e3]) => {
        if (onError) {
          onError([e1, e2, e3])
        }
      })
    }
  }, [sdk, dataSource, onStart, onEnd, onError])

  return <View style={{width: 0, height: 0}}><Canvas type='2d' id='canvas-poster' /></View>
}
