import { useState, useEffect } from "react";
import Taro, { useDidShow, useReady } from "@tarojs/taro";
import withLayout from "@/layout";
import {
  ScrollView,
  Image,
  RichText,
} from "@tarojs/components";
import Disclaimer from '@/components/Disclaimer'

import {
  // addActivityShareNum,
  signupActivity,
  favorActivity,
  cancelFavorActivity,
  queryActivityDetail,
} from "@/services/activity";
import { getImgURL } from "@/utils/image";
import getDateFormat from "@/utils/chatDate";

import "./index.scss";

const activityStatusDict = {
  0: {
    text: "立即参与",
    className: "yellow",
  },
  1: {
    text: "未开始",
    className: "blue",
  },
  2: {
    text: "已结束",
    className: "grey",
  },
  3: {
    text: "已参与",
    className: "yellow",
  },
};

export default withLayout((props) => {
  const { id } = props.router.params;
  const [detail, setDetail] = useState();
  const [canChoose, setCanChoose] = useState("none");

  const [IsPull, setPull] = useState(false);
  const [PullTimer, setPullTimer] = useState(null);

  const PageRefresh = () => {
    // 页面下拉刷新回调
    setPull(true);
  };

  useEffect(() => {
    // 下拉刷新触发
    if (IsPull) {
      clearTimeout(PullTimer);
      setPullTimer(
        setTimeout(() => {
          setPull(false);
        }, 2000)
      );
    }
  }, [IsPull]);

  const getDetail = (params) => {
    Taro.showLoading();

    queryActivityDetail(params).then((res) => {
      console.log(res, "queryActivityDetail");
      setDetail(res);

      Taro.hideLoading();
    });
  };

  useEffect(() => {
    if (id) {
      getDetail(id);
    }
  }, [id]);

  useReady(() => {
    console.log("Taro.showLoading()");
  });

  useDidShow(() => {
    // Taro.getCurrentPages()
    console.log("Taro.showLoading()");

    // console.log(Taro.getCurrentPages(),'Taro.showLoading()')
    // getDetail()
  });

  //收藏
  const handleFavo = () => {
    const { dynamicId, isSaved } = detail;
    if (isSaved) {
      cancelFavorActivity(dynamicId).then((res) => {
        Taro.showToast({
          title: "已取消收藏",
        });
        setDetail({
          ...detail,
          isSaved: 0,
        });
      });
    } else {
      favorActivity(dynamicId).then((res) => {
        Taro.showToast({
          title: "收藏成功",
        });
        setDetail({
          ...detail,
          isSaved: 1,
        });
      });
    }
    // savePoint({
    //   event: 'save',
    //   eventType: 'activity',
    //   targetType: 'dynamic',
    //   propertyName: '活动详情收藏',
    //   data: '{}'
    // }).then(res => {
    //   console.log('活动详情收藏')
    // })
  };

  const handleSignup = () => {
    const {
      detail: { buildingId, dynamicId, isSign },
    } = this.state;
    const {
      userInfo: {
        person: { phone, name, nickname },
      },
    } = this.props;

    if (isSign) {
      Taro.showToast({
        icon: "none",
        title: "你已报名成功",
      });
      return;
    }

    this.setState({
      canChoose: "block",
    });
  };

  return <>
  {
 detail && (
  <view className="Page activityDetail flex-v">
    <view className="flex-item">
      <view>
        <ScrollView
          scroll-y
          refresher-enabled
          refresher-triggered={IsPull}
          onrefresherrefresh={PageRefresh}
          refresher-background="#fff"
        >
          <view className="PageContent">
            <view className="Top">
              <Image
                mode="aspectFill"
                src={getImgURL(detail.bannerListImg)}
                className="centerLabel"
              ></Image>
            </view>

            <view className="Info">
              <view>
                <view className="Title flex-h">
                  <view className="flex-item">
                    <text>{detail.title}</text>
                  </view>
                  <text className="Tips">
                    {detail.enlisted || 0}人已报名
                  </text>
                </view>
                <text className="Time">
                  报名截止时间：
                  {getDateFormat(
                    new Date(detail.enlistEnd).valueOf(),
                    true,
                    "yyyy/M/d"
                  )}
                </text>
                {/* <text className="Name">“香颂 · 蔚澜半岛”</text> */}
                <view className="flex-h Address">
                  <text>地址：</text>
                  <view className="flex-item">
                    <text>{detail.address}</text>
                  </view>
                </view>
                <view className="flex-h Date">
                  <text>时间：</text>
                  <view className="flex-item">
                    <text>
                      {getDateFormat(
                        new Date(detail.startDate).valueOf(),
                        true,
                        "yyyy/M/d"
                      )}{" "}
                      -{" "}
                      {getDateFormat(
                        new Date(detail.endDate).valueOf(),
                        true,
                        "yyyy/M/d"
                      )}
                    </text>
                  </view>
                </view>
                <view className="Btn">
                  <text>分享好友</text>
                </view>
              </view>
            </view>

            <view className="ActivityIntro">
              <view className="Title">
                <text>活动介绍</text>
              </view>
              <Image
                mode="aspectFill"
                src={getImgURL(detail.imgUrl)}
                className="img"
              ></Image>
              <RichText nodes={detail.desc} />
              {/* <richText nodes={detail.desc} ></richText> */}
            </view>

            <Disclaimer />
          </view>
        </ScrollView>
      </view>
    </view>
    <view className="PageBottom flex-h">
      <view className="Share">
        <text className="iconfont icon-fenxiang"></text>
        <text>分享</text>
      </view>
      <view className="Collect" onClick={handleFavo}>
        <text
          className="iconfont icon-shoucang"
          style={detail.isSaved === 1 ? { color: "red" } : undefined}
        ></text>
        <text>收藏</text>
      </view>
      <view className="flex-item"></view>

      <text className="Post" onClick={handleSignup}>
        {activityStatusDict[detail.activityStatus]?.text}
      </text>
    </view>
  </view>
)
  }
    </>
   
  
});
